(Quack Profile) Profile Of A Duck In A Company
==============================================

PyPi: https://pypi.org/project/quackprofile/

This Package Is To Show How A Duck Can Get A Profile In A Company

How To Install
~~~~~~~~~~~~~~

Open CMD / Terminal

.. code:: python

   pip install quackprofile

How To Use
~~~~~~~~~~

-  Open Idle And Type…..

.. code:: python

   my = Profile('Quacker')
   my.hobby = ['Youtuber','Play Games']
   print(my.name)
   my.show_email()
   my.show_myart()
   my.show_hobby()

Made By LlamaIsTheBest Hope You Enjoy :D
